@@ -260,9 +260,15 @@ def get_account_history():
 def get_balance_by_id(account_id: int):
     account = get_account_by_id(account_id)
     all_account_histories = get_account_history()
-    account_hist = next(ah for ah in all_account_histories if ah['accountId'] == account['accountId'])
-    fact_values = [float(fh["factValue"]) for fh in account_hist["details"]]
-    return sum(fact_values) + account["startingRemainderValue"]
+    account_hist = next((ah for ah in all_account_histories if ah['accountId'] == account['accountId']), None)
+    if account_hist is None:
+        balance = 0.
+    else:
+        fact_values = [float(fh["factValue"]) for fh in account_hist["details"]]
+        if account["startingRemainderValue"] is None:
+            account["startingRemainderValue"] = 0
+        balance = sum(fact_values) + account["startingRemainderValue"]
+    return balance
 
 
 def get_balances():
